#!/usr/bin/env python
# -*- coding: utf-8 -*-
__author__ = 'Tong Miao (illemonati)'
__version__ = "0.0.1"
__status__ = 'Prototype'
__email__ = "tonymiaotong@tioft.tech"

from setuptools import setup

setup(
    name='warframe_alerts_rss',
    version='0.0.1',
    description='Get Warframe Alerts From http://content.warframe.com/dynamic/rss.php',
    author='Tong Miao (illemonati)',
    author_email = 'tonymiaotong@tioft.tech',
    packages=['warframe_alerts_rss'],
    url='https://github.com/hackcrafter427/warframe_alerts_rss',
)
